<?php
/**
 * 親テーマの翻訳ファイルをチャイルドテーマの翻訳ファイルで置換
 */
if ( !function_exists( 'raindrops_override_mo' ) ) {

	function raindrops_override_mo( $mofile, $domain ) {
		
		if ( $domain == 'twentyseventeen'  ) {
			
			$mofile = get_stylesheet_directory() . '/languages/twentyseventeen-ja.mo';
		}

		return $mofile;
	}
}
/**
 * スタイルシートの読み込みとスタイルシートの読み込み順の修正
 * 
  <link rel='stylesheet' id='twentyseventeen-fonts-css'  href='' type='text/css' media='all' />
  <link rel='stylesheet' id='twentyseventeen-style-css'  href='' type='text/css' media='all' />
  <!--[if lt IE 9]><link rel='stylesheet' id='twentyseventeen-ie8-css'  href='' type='text/css' media='all' /><![endif]-->
  <link rel='stylesheet' id='twentyseventeen-child-style-css'  href='' type='text/css' media='all' />
 * @see http://tenman.info/labo/snip/archives/7322
 */
add_action( 'wp_enqueue_scripts', 'theme_enqueue_styles' );

function theme_enqueue_styles() {

	$twentry_seventeen_fonts_url = twentyseventeen_fonts_url();
	/**
	 * 
	 * load font stylesheet
	 * 翻訳ファイルとの依存性があるので、 空白文字を返していないか、チェックが必要です。
	 * 日本語環境などで、空文字を返す場合には、twentyseventeen-style依存スタイルtwentyseventeen-fontsを指定すると、スタイルシートが適用されなくなります
	 */
	if ( !empty( $twentry_seventeen_fonts_url ) ) {
		wp_enqueue_style( 'twentyseventeen-fonts', $twentry_seventeen_fonts_url, array(), null );
		// load parent stylesheet
		wp_enqueue_style( 'twentyseventeen-style', get_template_directory_uri() . '/style.css', array( 'twentyseventeen-fonts' ) );
	} else {
		// load parent stylesheet
		wp_enqueue_style( 'twentyseventeen-style', get_template_directory_uri() . '/style.css', array() );
	}
	// ie style
	wp_enqueue_style( 'twentyseventeen-ie8', get_theme_file_uri( '/assets/css/ie8.css' ), array( 'twentyseventeen-style' ), '1.0' );
	wp_style_add_data( 'twentyseventeen-ie8', 'conditional', 'lt IE 9' );
	// load child stylesheet
	wp_enqueue_style( 'twentyseventeen-child-style', get_stylesheet_directory_uri() . '/style.css', array( 'twentyseventeen-ie8' ), filemtime( get_theme_file_path( 'style.css' ) ) );
}

add_action( 'after_setup_theme', 'my_theme_setup' );

if ( !function_exists( 'my_theme_setup' ) ) {

	function my_theme_setup() {
		add_filter( 'load_textdomain_mofile', 'raindrops_override_mo', 10, 2 );
		add_filter( 'body_class', 'my_sidebar_control', 11 );
		add_action( 'wp_print_styles', 'my_styles_method', 11 );
	}
}

function my_get_sidebar() {
	global $template;

	if ( twentyseventeen_is_frontpage() ) {

		$frontpage_id	 = get_option( 'page_on_front' );
		$template_name	 = get_post_meta( $frontpage_id, '_wp_page_template' );
		$template_name	 = basename( $template_name[ 0 ], '.php' );

		if ( 'col2' == $template_name ) {
			get_sidebar();
		}
	} else {
		$template_name = basename( $template, '.php' );

		if ( 'col2' == $template_name ) {
			get_sidebar();
		}
	}
}

function my_sidebar_control( $classes ) {
	global $template;

	$template_name = basename( $template, '.php' );

	if ( twentyseventeen_is_frontpage() ) {
		$frontpage_id	 = get_option( 'page_on_front' );
		$template_name	 = get_post_meta( $frontpage_id, '_wp_page_template' );
		$template_name	 = basename( $template_name[ 0 ], '.php' );
	}

	if ( 'col1' == $template_name ) {

		if ( ( $key = array_search( 'has-sidebar', $classes ) ) !== false ) {
			unset( $classes[ $key ] );
		}
		return $classes;
	}
	if ( 'col2' == $template_name ) {

		$classes[] = 'has-sidebar';

		return $classes;
	}
	return $classes;
}

// @see http://tenman.info/labo/snip/archives/6698
add_action( 'customize_register', 'textdomain_customize_register' );

if ( !function_exists( 'textdomain_customize_register' ) ) {

	function textdomain_customize_register( $wp_customize ) {

		$wp_customize->add_section( 'my_custom_section', array( 'title' => __( 'Custom Control', 'textdomain' ), 'priority' => 33 ) );
		$wp_customize->add_setting( 'custom_sidebar', array(
			'default'			 => 36,
			'sanitize_callback'	 => 'absint',
		) );
		$wp_customize->add_control( 'custom_sidebar', array( 'custom_sidebar',
			'label'			 => esc_html__( 'Sidebar Width', 'textdomain' ),
			'section'		 => 'my_custom_section',
			'settings'		 => 'custom_sidebar',
			'type'			 => 'range',
			'input_attrs'	 => array(
				'min'	 => 18,
				'max'	 => 36,
				'step'	 => 1,
			),
		) );


		$wp_customize->add_setting( 'custom_page_width', array(
			'default'			 => 48,
			'sanitize_callback'	 => 'absint',
		) );
		$wp_customize->add_control( 'custom_page_width', array( 'custom_page_width',
			'label'			 => esc_html__( 'Page Width', 'textdomain' ),
			'section'		 => 'my_custom_section',
			'settings'		 => 'custom_page_width',
			'type'			 => 'number',
			'input_attrs'	 => array( 'min' => 48, 'max' => 96, ),
		) );
	}

}

// @see http://tenman.info/labo/snip/archives/2382
function my_styles_method() {
	global $content_width;
	$custom_css		 = '';
	$sidebar_width	 = absint( get_theme_mod( 'custom_sidebar' ) );
	$primary_width	 = 96 - $sidebar_width;
	if ( !empty( $sidebar_width ) ) {
		$custom_css .= "@media screen and (min-width: 48em){
		.has-sidebar .wrap #secondary{ 	width:{$sidebar_width}%;	}
	    .has-sidebar .wrap #primary{ 	width:{$primary_width}%;	}
		
		";
	}
	$page_width = absint( get_theme_mod( 'custom_page_width' ) );
	if ( !empty( $page_width ) ) {
		$custom_css .= "
		.site-content > .wrap { width:{$page_width}em;max-width:100vw;}
		.site-content > .wrap .wrap{max-width:none; /*max-width:{$content_width}px;*/}
		}";
	}
	$custom_css .= '}';
	wp_add_inline_style( 'twentyseventeen-child-style', $custom_css );
}